@@ -7,7 +7,7 @@
    This file is part of Valgrind, a dynamic binary instrumentation
    framework.
 
-   Copyright (C) 2000-2015 Julian Seward
+   Copyright (C) 2000-2017 Julian Seward
       jseward@acm.org
 
    This program is free software; you can redistribute it and/or
@@ -21,9 +21,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307, USA.
+   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
    The GNU General Public License is contained in the file COPYING.
 */
@@ -263,6 +261,9 @@ extern void VG_(details_bug_reports_to)   ( const HChar* bug_reports_to );
 /* Should __libc_freeres() be run?  Bugs in it can crash the tool. */
 extern void VG_(needs_libc_freeres) ( void );
 
+/* Should __gnu_cxx::__freeres() be run?  Bugs in it can crash the tool. */
+extern void VG_(needs_cxx_freeres) ( void );
+
 /* Want to have errors detected by Valgrind's core reported?  Includes:
    - pthread API errors (many;  eg. unlocking a non-locked mutex) 
      [currently disabled]
@@ -460,7 +461,7 @@ extern void VG_(needs_print_stats) (
    of an address ? */
 extern void VG_(needs_info_location) (
    // Get and pp information about Addr
-   void (*info_location)(Addr)
+   void (*info_location)(DiEpoch, Addr)
 );
 
 /* Do we need to see variable type and location information? */
@@ -473,12 +474,16 @@ extern void VG_(needs_var_info) ( void );
 extern void VG_(needs_malloc_replacement)(
    void* (*pmalloc)               ( ThreadId tid, SizeT n ),
    void* (*p__builtin_new)        ( ThreadId tid, SizeT n ),
+   void* (*p__builtin_new_aligned)( ThreadId tid, SizeT n, SizeT align ),
    void* (*p__builtin_vec_new)    ( ThreadId tid, SizeT n ),
+   void* (*p__builtin_vec_new_aligned)( ThreadId tid, SizeT n, SizeT align ),
    void* (*pmemalign)             ( ThreadId tid, SizeT align, SizeT n ),
    void* (*pcalloc)               ( ThreadId tid, SizeT nmemb, SizeT size1 ),
    void  (*pfree)                 ( ThreadId tid, void* p ),
    void  (*p__builtin_delete)     ( ThreadId tid, void* p ),
+   void  (*p__builtin_delete_aligned)     ( ThreadId tid, void* p, SizeT align ),
    void  (*p__builtin_vec_delete) ( ThreadId tid, void* p ),
+   void  (*p__builtin_vec_delete_aligned) ( ThreadId tid, void* p, SizeT align ),
    void* (*prealloc)              ( ThreadId tid, void* p, SizeT new_size ),
    SizeT (*pmalloc_usable_size)   ( ThreadId tid, void* p), 
    SizeT client_malloc_redzone_szB
@@ -608,6 +613,9 @@ void VG_(track_die_mem_stack)                  (void(*f)(Addr a, SizeT len));
 /* Used for redzone at end of thread stacks */
 void VG_(track_ban_mem_stack)      (void(*f)(Addr a, SizeT len));
 
+/* Used to report VG_USERREQ__STACK_REGISTER client requests */
+void VG_(track_register_stack)     (void(*f)(Addr start, Addr end));
+
 /* These ones occur around syscalls, signal handling, etc */
 void VG_(track_pre_mem_read)       (void(*f)(CorePart part, ThreadId tid,
                                              const HChar* s, Addr a, SizeT size));
